{pkgs, ...}: {
  imports = [
    ./programs
    ./services
    ./shell
    ./wayland
    ./email.nix
    ./lf
    ./neovim
  ];

  home = {
    username = "tacocat";
    homeDirectory = "/home/tacocat";
    stateVersion = "24.05";
    sessionVariables = {
      EDITOR = "nvim";
      BAT_THEME = "ansi";
      DOTNET_ROOT = "$HOME/.dotnet";
    };
    sessionPath = [
      "$HOME/.local/bin"
      "$HOME/.dotnet"
    ];
    packages = with pkgs; [
      fd
      emacs
      vimpc
      ashuffle
      ardour
      giada
      carla
      surge-XT
      atkinson-hyperlegible
      rsgain
      swayimg
      virtualenv
      whipper
      unzip
      mpc-cli
      nicotine-plus
      texliveFull
      ripgrep
      matlab
      octave
      mpv
      krita
      tree
      gimp
      rtorrent
      wireguard-tools
      xournalpp
      cardinal
      tor-browser
      libreoffice
      notify-desktop
      aspell
      aspellDicts.en
      qalculate-qt
      zathura
      wineWowPackages.waylandFull
      comic-mono
      maple-mono
      jetbrains-mono
      fira-code
      mononoki
      inter
      (nerdfonts.override {fonts = ["FiraCode" "Mononoki" "NerdFontsSymbolsOnly"];})
      pandoc
      pdftk
      lua
      python3
      python311Packages.eyed3
      pamixer
      networkmanagerapplet
      htop
      p7zip
      cachix
      aria
      fastfetch
      gcc
      gcc-arm-embedded-13
      gnumake
      webcord
    ];
  };

  programs.nix-index.enable = true;

  # programs.gpg = {
  #   enable = true;
  # };

  fonts.fontconfig.enable = true;

  news.display = "silent";

  xdg = {
    enable = true;
    mimeApps = {
      enable = true;
      defaultApplications = {
        "application/pdf" = ["org.pwmt.zathura-pdf-mupdf.desktop"];
        "image/jpg" = ["swayimg.desktop"];
        "image/jpeg" = ["swayimg.desktop"];
        "image/png" = ["swayimg.desktop"];
        "image/gif" = ["swayimg.desktop"];
        "image/svg+xml" = ["swayimg.desktop"];
        "image/webp" = ["swayimg.desktop"];
        "image/heif" = ["swayimg.desktop"];
        "image/bmp" = ["swayimg.desktop"];
      };
    };
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  # ------------ GTK ------------

  gtk = {
    enable = true;
    theme = {
      package = pkgs.rose-pine-gtk-theme;
      name = "oomox-rose-pine-moon";
    };
    iconTheme = {
      package = pkgs.papirus-icon-theme;
      name = "Papirus";
    };
  };

  # xdg.configFile."./" = {
  #   source = ./.config;
  #   recursive = true;
  # };

	xdg.configFile."emacs/init.el".source = ./emacs/init.el;
	xdg.configFile."emacs/early-init.el".source = ./emacs/early-init.el;
	xdg.configFile."emacs/straight/versions/default.el".source = ./emacs/default.el;

}
